@@ -50,7 +50,7 @@ from JABWrapper.jab_types import (
 from JABWrapper.utils import ReleaseEvent
 
 
-log_path = os.path.join(os.getenv("ROBOT_ARTIFACTS", ""), "jab_wrapper.log")
+log_path = os.path.join(os.path.abspath(os.getenv("ROBOT_ARTIFACTS", "")), "jab_wrapper.log")
 if not os.path.exists(os.path.dirname(log_path)):
     os.mkdir(os.path.dirname(log_path))
 logging_file_handler = logging.FileHandler(log_path, "w", "utf-8")
@@ -116,9 +116,11 @@ class APIException(Exception):
 
 class JavaAccessBridgeWrapper:
     def __init__(self, ignore_callbacks=False) -> None:
-        logging.debug("Loading WindowsAccessBridge")
+        self.ignore_callbacks = ignore_callbacks
+        self._init()
 
-        self._ignore_callbacks = ignore_callbacks
+    def _init(self) -> None:
+        logging.debug("Loading WindowsAccessBridge")
 
         if "RC_JAVA_ACCESS_BRIDGE_DLL" not in os.environ:
             raise OSError("Environment variable: RC_JAVA_ACCESS_BRIDGE_DLL not found")
@@ -127,7 +129,7 @@ class JavaAccessBridgeWrapper:
         self._wab: cdll = cdll.LoadLibrary(os.path.normpath(os.environ['RC_JAVA_ACCESS_BRIDGE_DLL']))
         logging.debug("WindowsAccessBridge loaded succesfully")
         self._define_functions()
-        if not self._ignore_callbacks:
+        if not self.ignore_callbacks:
             self._define_callbacks()
             self._set_callbacks()
         self._wab.Windows_run()
@@ -136,14 +138,14 @@ class JavaAccessBridgeWrapper:
         self._vmID = c_long()
         self.context = JavaObject()
 
-        self._current_window: str = ''
+        self._expected_window: str = ''
 
         # Any reader can register callbacks here that are executed when AccessBridge events are seen
         self._context_callbacks: dict[str, List[Callable[[JavaObject], None]]] = dict()
 
     def shutdown(self):
         self._context_callbacks = dict()
-        if not self._ignore_callbacks:
+        if not self.ignore_callbacks:
             self._remove_callbacks()
 
     def _define_functions(self) -> None:
@@ -491,7 +493,7 @@ class JavaAccessBridgeWrapper:
 
     def _enumerate_windows(self, hwnd, lParam) -> bool:
         if not hwnd:
-            logging.error("Invalid window handle={hwnd}")
+            logging.error(f"Invalid window handle={hwnd}")
             return True
 
         length = user32.GetWindowTextLengthW(hwnd) + 1
@@ -506,7 +508,7 @@ class JavaAccessBridgeWrapper:
             return True
         if isJava:
             logging.debug(f"found java window={title}")
-            regex = re.compile(self._current_window)
+            regex = re.compile(self._expected_window)
             if re.match(regex, title):
                 logging.debug(f"found matching window={title}")
                 self._hwnd = hwnd
@@ -523,7 +525,7 @@ class JavaAccessBridgeWrapper:
         self._vmID = vm_id
         self.context = context
 
-    def get_current_windows_handle(self) -> wintypes.HWND:
+    def get_expected_windows_handle(self) -> wintypes.HWND:
         return self._hwnd
 
     def release_object(self, context: JavaObject) -> None:
@@ -555,22 +557,28 @@ class JavaAccessBridgeWrapper:
         Raises:
             Exception: Window not found.
         """
+        self._context_callbacks.clear()
+        self._hwnd: wintypes.HWND = None
+        self._vmID = c_long()
+        self.context = JavaObject()
+
         # Add the title as the current context and find the correct window
-        self._current_window = title
-        self._vmID = None
-        self.context = None
+        self._expected_window = title
         windows = WNDENUMPROC(self._enumerate_windows)
         if not windll.user32.EnumWindows(windows, 0):
             raise WinError()
         if not self._hwnd or not self._vmID or not self.context:
             raise Exception("Window not found")
         logging.info("Found Java window text={}, hwnd={} vmID={} context={}\n".format(
-            self._current_window,
+            self._expected_window,
             self._hwnd,
             self._vmID,
             self.context,
         ))
 
+        if not self._hwnd:
+            raise Exception(f"Window not found={self._expected_window}")
+
         # Return the PID of found window
         _, found_pid = win32process.GetWindowThreadProcessId(self._hwnd)
         return found_pid
@@ -1668,6 +1676,9 @@ class JavaAccessBridgeWrapper:
         else:
             self._context_callbacks[name] = [callback]
 
+    def clear_callbacks(self):
+        self._context_callbacks.clear()
+
     """
     Define the callback handlers
     """
